@@ -31,6 +31,7 @@ from gi.repository import Gio, Grl, Gtk, GObject
 import gnomemusic.utils as utils
 
 from gnomemusic.albumart import AlbumArt
+from gnomemusic.coredisc import CoreDisc
 
 
 class CoreAlbum(GObject.GObject):
@@ -45,7 +46,7 @@ class CoreAlbum(GObject.GObject):
     media = GObject.Property(type=Grl.Media)
     title = GObject.Property(type=str)
     url = GObject.Property(type=str)
-    year = GObject.Property(type=str, default="----")
+    year = GObject.Property(type=str, default=None)
 
     def __init__(self, application, media):
         """Initiate the CoreAlbum object
@@ -58,7 +59,6 @@ class CoreAlbum(GObject.GObject):
         self._application = application
         self._coregrilo = application.props.coregrilo
         self._model = None
-        self._selected = False
         self._thumbnail = None
 
         self.update(media)
@@ -77,20 +77,9 @@ class CoreAlbum(GObject.GObject):
 
     def _get_album_model(self):
         disc_model = Gio.ListStore()
-        disc_model_sort = Gtk.SortListModel.new(disc_model)
-
-        def _disc_order_sort(disc_a, disc_b, data=None):
-            order = disc_a.props.disc_nr - disc_b.props.disc_nr
-            if order < 0:
-                return Gtk.Ordering.SMALLER
-            elif order > 0:
-                return Gtk.Ordering.LARGER
-            else:
-                return Gtk.Ordering.EQUAL
-
-        disc_sorter = Gtk.CustomSorter()
-        disc_sorter.set_sort_func(_disc_order_sort)
-        disc_model_sort.set_sorter(disc_sorter)
+        disc_no_exp = Gtk.PropertyExpression.new(CoreDisc, None, "disc_nr")
+        disc_sorter = Gtk.NumericSorter.new(disc_no_exp)
+        disc_model_sort = Gtk.SortListModel.new(disc_model, disc_sorter)
 
         self._coregrilo.get_album_discs(self.props.media, disc_model)
 
@@ -109,9 +98,6 @@ class CoreAlbum(GObject.GObject):
 
     def _on_list_items_changed(self, model, position, removed, added):
         with self.freeze_notify():
-            for coredisc in model:
-                coredisc.props.selected = self.props.selected
-
             if added > 0:
                 for i in range(added):
                     coredisc = model[position + i]
@@ -126,24 +112,6 @@ class CoreAlbum(GObject.GObject):
 
         self.props.duration = duration
 
-    @GObject.Property(type=bool, default=False)
-    def selected(self):
-        return self._selected
-
-    @selected.setter  # type: ignore
-    def selected(self, value):
-        if value == self._selected:
-            return
-
-        self._selected = value
-
-        # The model is loaded on-demand, so the first time the model is
-        # returned it can still be empty. This is problem for returning
-        # a selection. Trigger loading of the model here if a selection
-        # is requested, it will trigger the filled model update as
-        # well.
-        self.props.model.items_changed(0, 0, 0)
-
     @GObject.Property(type=str, default=None)
     def thumbnail(self):
         """Album art thumbnail retrieval
