@@ -22,7 +22,10 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
+from __future__ import annotations
+import asyncio
 import re
+import typing
 
 from gi.repository import Gio, GLib
 
@@ -31,6 +34,12 @@ from gnomemusic.gstplayer import Playback
 from gnomemusic.player import RepeatMode
 from gnomemusic.widgets.songwidget import SongWidget
 
+if typing.TYPE_CHECKING:
+    from gi.repository import GObject
+
+    from gnomemusic.coresong import CoreSong
+    from gnomemusic.player import Player
+
 
 class DBusInterface:
 
@@ -41,17 +50,19 @@ class DBusInterface:
         :param str path: object path
         :param GtkApplication application: The Application object
         """
+        self._con: Gio.DBusConnection
         self._log = application.props.log
         self._path = path
         self._signals = None
-        Gio.bus_get(Gio.BusType.SESSION, None, self._bus_get_sync, name)
 
-    def _bus_get_sync(self, source, res, name):
+        asyncio.create_task(self._get_bus(name))
+
+    async def _get_bus(self, name: str) -> None:
         try:
-            self._con = Gio.bus_get_finish(res)
-        except GLib.Error as e:
+            self._con = await Gio.bus_get(Gio.BusType.SESSION, None)
+        except GLib.Error as error:
             self._log.warning(
-                "Unable to connect to to session bus: {}".format(e.message))
+                f"Unable to connect to the session bus: {error.message}")
             return
 
         Gio.bus_own_name_on_connection(
@@ -74,8 +85,7 @@ class DBusInterface:
                     'interface': interface.name, 'args': args}
 
             self._con.register_object(
-                object_path=self._path, interface_info=interface,
-                method_call_closure=self._on_method_call)
+                self._path, interface, self._on_method_call, None, None)
 
         self._method_inargs = method_inargs
         self._method_outargs = method_outargs
@@ -318,6 +328,8 @@ class MPRIS(DBusInterface):
         self._previous_loop_status = ""
         self._previous_mpris_playlist = self._get_active_playlist()
         self._previous_playback_status = "Stopped"
+        self._thumbnail_id = 0
+        self._current_coresong = None
 
     def _get_playback_status(self):
         state = self._player.props.state
@@ -376,11 +388,32 @@ class MPRIS(DBusInterface):
             metadata['xesam:trackNumber'] = GLib.Variant('i', track_nr)
 
         art_url = coresong.props.thumbnail
-        if art_url not in ["generic", "loading"]:
+        if (art_url == "generic"
+                and self._current_coresong == coresong):
+            self._thumbnail_id = coresong.connect(
+                "notify::thumbnail", self._on_thumbnail_changed)
+        else:
             metadata['mpris:artUrl'] = GLib.Variant('s', art_url)
 
         return metadata
 
+    def _on_thumbnail_changed(
+            self, coresong: CoreSong, param: GObject.ParamSpecString) -> None:
+        """Updates MPRIS metadata when a song's thumbnail changes.
+
+        :param coresong: The song with the new thumbnail.
+        :param param_spec: Metadata about the changed property.
+        :param user_data: Optional; unused.
+        """
+        if coresong != self._player.props.current_song:
+            return
+
+        properties = {}
+        properties["Metadata"] = GLib.Variant(
+            "a{sv}", self._get_metadata(coresong))
+        self._properties_changed(
+            MPRIS.MEDIA_PLAYER2_PLAYER_IFACE, properties, [])
+
     def _get_song_dbus_path(self, coresong=None, index=None):
         """Convert a Grilo media to a D-Bus path
 
@@ -462,7 +495,14 @@ class MPRIS(DBusInterface):
             current_core_object)
         return (True, mpris_playlist)
 
-    def _on_current_song_changed(self, player):
+    def _on_current_song_changed(self, player: Player) -> None:
+        if (self._thumbnail_id != 0
+                and self._current_coresong):
+            self._current_coresong.disconnect(self._thumbnail_id)
+            self._thumbnail_id = 0
+
+        self._current_coresong = player.props.current_song
+
         # In repeat song mode, no metadata has changed if the
         # player was already started
         if self._player.props.repeat_mode == RepeatMode.SONG:
